@@ -25,6 +25,8 @@ __PACKAGE__->add_columns(
   { data_type => "text", is_nullable => 1 },
   "remote_serial",
   { data_type => "text", is_nullable => 1 },
+  "raw_speed",
+  { data_type => "bigint", is_nullable => 1 },
 );
 __PACKAGE__->set_primary_key("port", "ip");
 
